@@ -64,15 +64,16 @@ class AttachmentInline(admin.TabularInline):
 class NotificationEventAdmin(admin.ModelAdmin):
     list_display = ['id', 'title', 'owner', 'smtp_provider', 'template', 'is_active', 'created_time', 'updated_time']
     list_filter = ['is_active', 'created_time', 'updated_time']
-    filter_horizontal = ['recipients']
-    raw_id_fields = ['owner', 'smtp_provider', 'notification_group', 'template']
+    filter_horizontal = ['recipients', 'notification_groups']
+    raw_id_fields = ['owner', 'smtp_provider', 'template']
     readonly_fields = ['created_time', 'updated_time']
     inlines = [AttachmentInline]
 
     def get_queryset(self, request):
         queryset = super().get_queryset(request)
-        return queryset.prefetch_related('attachments', 'recipients').select_related('notification_group', 'template',
-                                                                                     'smtp_provider', 'owner').all()
+        queryset = queryset.prefetch_related('attachments', 'recipients', 'notification_groups')
+        queryset = queryset.select_related('template', 'smtp_provider', 'owner').all()
+        return queryset
 
 
 @admin.register(OutgoingMessage)
