@@ -132,7 +132,7 @@ class OutgoingMessageSerializer(serializers.ModelSerializer):
     class Meta:
         model = OutgoingMessage
         fields = ['id', 'notification_event_detail', 'recipient', 'subject', 'status', 'status_display',
-                  'outgoing_message_type', 'outgoing_message_type_display']
+                  'outgoing_message_type', 'outgoing_message_type_display', 'created_time', 'updated_time']
 
 
 class OutgoingMessageNotificationSerializer(serializers.Serializer):
