@@ -91,7 +91,7 @@ class OutgoingMessageViewSet(mixins.ListModelMixin,
     pagination_class = CustomLimitOffsetPagination
     filter_backends = [DjangoFilterBackend, filters.OrderingFilter]
     ordering_fields = ['id']
-    filter_fields = ['outgoing_message_type', 'status']
+    filter_fields = ['outgoing_message_type', 'status', 'notification_event']
 
     def get_queryset(self):
         queryset = super().get_queryset()
