@@ -4,8 +4,10 @@ from notification_system.utils import get_user_common_data
 
 
 def broadcast_event_messages_to_recipients(event_message_id):
-    notification_event = NotificationEvent.objects.prefetch_related('notification_group__members', 'attachments')
-    notification_event = notification_event.select_related('smtp_provider', 'owner', 'notification_group', 'template')
+    notification_event = NotificationEvent.objects.prefetch_related('notification_groups__members', 'attachments')
+    notification_event = notification_event.prefetch_related('notification_groups')
+    notification_event = notification_event.select_related('smtp_provider', 'owner', 'template')
+
     notification_event = notification_event.get(id=event_message_id)
 
     subject = notification_event.get_subject()
